# -*- coding: utf-8 -*-
# Copyright 2023 Cohesity Inc.

class SeverityEnum(object):

    """Implementation of the 'Severity' enum.
    Specifies the severity level of an Alert. kCritical - Alerts whose severity
    type is Critical. kWarning - Alerts whose severity type is Warning. kInfo -
    Alerts whose severity type is Info.


    Attributes:
        KCRITICAL: TODO: type description here.
        KWARNING: TODO: type description here.
        KINFO: TODO: type description here.

    """

    KCRITICAL = 'kCritical'

    KWARNING = 'kWarning'

    KINFO = 'kInfo'
